@@ -97,6 +97,8 @@ void            ev_window_handle_annot_popup             (EvWindow       *ev_win
                                                           EvAnnotation   *annot);
 EvMetadata     *ev_window_get_metadata			 (EvWindow	 *ev_window);
 gint            ev_window_get_metadata_sidebar_size      (EvWindow       *ev_window);
+GtkWidget      *ev_window_get_sidebar			 (EvWindow	 *ev_window);
+GtkWidget      *ev_window_get_find_sidebar		 (EvWindow	 *ev_window);
 
 G_END_DECLS
 
